#
# spec file for package python-django-reversion
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-reversion
Version:        5.1.0
Release:        1.3
Summary:        A Django extension that provides version control for model instances
License:        BSD-3-Clause
URL:            https://github.com/etianen/django-reversion
Source:         https://files.pythonhosted.org/packages/source/d/django_reversion/django_reversion-%{version}.tar.gz
Patch0:         only-sqlite-test-db.patch
BuildRequires:  %{python_module Django > 2.0}
BuildRequires:  %{python_module base > 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django > 2.0
Obsoletes:      python-django-reversion-doc
Obsoletes:      python-django-reversion-lang
BuildArch:      noarch
%python_subpackages

%description
Django-reversion is an extension to the Django web framework that provides
version control for model instances.

-  Roll back to any point in a model instance's history.
-  Recover deleted model instances.
-  Simple admin integration.

%prep
# Tests need running PGSQL and MYSQL
# https://github.com/etianen/django-reversion/issues/902
%autosetup -p1 -n django_reversion-%{version}
sed -i 's/databases = {"default", .*"postgres"}/databases = {"default"}/' tests/test_app/tests/test_*.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
cd tests
export DJANGO_SETTINGS_MODULE=test_project.settings
%pytest -k 'not (testAddMetaMultDb or MultiDb or MySQL or MySql or Postgres or testCreateInitialRevisionsDb or testCreateInitialRevisionsModelDb or testDeleteRevisionsDb or testGetForModelDb or testGetForObjectDb or testGetForObjectModelDb or testGetForObjectReferenceModelDb or testGetDeletedDb or testGetDeletedModelDb or testDeleteRevisionsModelDb)'

%files %{python_files}
%doc README.rst CHANGELOG.rst
%license LICENSE
%{python_sitelib}/reversion
%{python_sitelib}/django_reversion-%{version}.dist-info

%changelog
* Mon Nov 11 2024 Markéta Machová <mmachova@suse.com>
- Update to 5.1.0
  * Switch call from removed is_hidden method to hidden property
  * Remove irrelevant comment
  * Re-introduce bulk_create on supported databases
* Thu Mar 28 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Thu Feb 22 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 5.0.12:
  * Improved the Chinese translation
  * Fix N+1 queries while rendering the ``recover_list.html`` template
  * Fix ``get_deleted``
  * Speed up ``get_deleted``
  * Fix handling case of missing object in admin revert
  * Handling case of missing object in admin revert
- Switch to pyproject and autosetup macros.
- Refresh only-sqlite-test-db.patch
* Sat Jan  7 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0.4:
  * Fix warning log formatting for failed reverts (@tony).
  * A revision will no longer be created if a transaction is marked as
    rollback, as this would otherwise cause an additional database error
  * A warning log is now emitted if a revert fails due to database integrity
    errors, making debugging the final
  ``RevertError`` easier.
  * Fixed doc builds on readthedocs (@etianen).
  * Fix admin detail view in multi-database configuration (@atten).
  * Added support for using django-reversion contexts in ``asyncio`` tasks
  * Improved performance of `createinitialrevisions` management command
* Tue Dec 28 2021 John Vandenberg <jayvdb@gmail.com>
- Activate test suite using only-sqlite-test-db.patch
- Remove build dependencies mysqlclient & psycopg2
- Update to v4.0.1
  * Django 4.0b support
  * Optimized VersionQuerySet.get_deleted
- from v4.0.0
  * Breaking: The create_revision view decorator and RevisionMiddleware
    no longer roll back the revision and database transaction on
    response status code >= 400. It's the responsibility of the
    view to use transaction.atomic() to roll back any invalid data.
    This can be enabled globally by setting ATOMIC_REQUESTS=True.
  * Fixing gettext plural forms with Django
  * Deprecation removals
  * Documentation fixes
- from v3.0.9
  * Significant speedup to Version.objects.get_deleted(...)
    database query for PostgreSQL
  * Testing against Django 3.1
  * Django 4.0 compatibility improvements
- from v3.0.8
  * Added use_natural_foreign_keys option to reversion.register()
  * Documentation improvments and minor fixes
  * Dropped support for Django 1.11 LTS.
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0.7:
  * Packaging improvements (@michael-k).
  * Removing deprecated usages of force_text (@Tenzer).
  * Documentation fixes (@chicheng).
  * Removing deprecated usages of ugettext_lazy (@François GUÉRIN).
  * Slovenian translation (@Bor Plestenjak).
* Fri Dec  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix the requires on the Django as it really works with > 1.11 and
  does not support python 2 anymore
* Thu Dec  5 2019 Martin Herkt <9+suse@cirno.systems>
- Update to 3.0.5:
  * Improved performance of `get_deleted` for large datasets.
  * Django 3.0 compatibility.
  * Drops Django <= 1.11 compatibility.
  * Fixed errors in manageement commands when
    `django.contrib.admin` is not in `INSTALLED_APPS`.
* Wed May 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0.4:
  * Various dependency fixes
- Upstreamed 0000-Remove-django.contrib.admin-dependency.patch
* Sat May  4 2019 Martin Herkt <9+suse@cirno.systems>
- Add 0000-Remove-django.contrib.admin-dependency.patch
  https://github.com/etianen/django-reversion/issues/744
* Wed Apr 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not mess around with doc/lang subpackages, the docs are
  all online and the lang split actually breaks as the lang part
  is hard-required for the python to work in most cases
* Mon Mar 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix typo python2->python3
* Thu Jan 24 2019 Martin Herkt <9+suse@cirno.systems>
- Update to version 3.0.3:
  * Improved performance of many reversion database queries using
    `EXISTS` subquery.
  * Added support for Django 2.1 `view` permission.
* Tue Nov  6 2018 Martin Herkt <9+suse@cirno.systems>
- Update to version 3.0.2:
  * Removed squashed migrations, as they subtly messed up the
    Django migrations framework
* Mon Oct 29 2018 Martin Herkt <9+suse@cirno.systems>
- Update to version 3.0.1:
  * Added squashed migrations back in to allow older installations
    to upgrade
  * Fixed TypeError exception when accessing m2m_data attribute
    from a field that points to Django’s User model
* Fri Jul 20 2018 9+suse@cirno.systems
- Update to version 3.0.0:
  * Breaking: 'Revision.commment' now contains the raw JSON change
    message generated by django admin, rather than a string.
    Accesing 'Revision.comment' directly is no longer recommended.
    Instead, use 'Revision.get_comment()'.
  * Breaking: django-reversion now uses '_base_manager' to
    calculate deleted models, not '_default_manager'. This change
    will only affect models that perform default filtering in their
    '_default_manager'
  * Added 'request_creates_revision' hook to 'RevisionMiddleware'
    and 'views.create_revision'.
  * Added 'revision_request_creates_revision' hook to
    'views.RevisionMixinView'.
  * Added '--meta' flag to './manage.py createrevisions'
  * Fixed bug when reverting deleted nested inlines
  * Added tests for django 2.1
* Mon May 28 2018 9+suse@cirno.systems
- Rewrite spec file to current conventions
  * Build documentation
  * lang packages
  * Not running tests as these require configuring MySQL and PostgreSQL
- Update to version 2.0.13:
  * Years worth of changes, including a breaking major version bump.
    See CHANGELOG.rst in the package documentation path for details.
* Wed Apr 22 2015 mcihar@suse.cz
- Update to version 1.8.6:
  - Support for MySQL utf8mb4 (@alexhayes).
  - Fixing some Django deprecation warnings (Drew Hubl, @khakulov, @adonm).
  - Versions passed through by reversion.post_revision_commit now contain a primary key (@joelarson).
  - Added support for proxy models (@AgDude, @bourivouh).
  - Allowing registration of models with django-reversion using custom signals (@ErwinJunge).
  - Fixing some Django deprecation warnings (@skipp, @narrowfail).
  - Fixing including legacy south migrations in PyPi package (@GeyseR).
  - Provisional Django 1.7 support (@etianen).
  - Multi-db and multi-manager support to management commands (@marekmalek).
  - Added index on reversion.date_created (@rkojedzinszky).
  - Minor bugfixes and documentation improvements (@coagulant).
  - reversion.register() can now be used as a class decorator (@aquavitae).
  - Danish translation (@Vandborg).
  - Improvements to Travis CI integration (@thedrow).
  - Simplified Chinese translation (@QuantumGhost).
  - Minor bugfixes and documentation improvements (@marekmalek, @dhoffman34, @mauricioabreu, @mark0978).
  - Slovak translation (@jbub).
  - Deleting a user no longer deletes the associated revisions (@daaray).
  - Improving handling of inline models in admin integration (@blueyed).
  - Improving error messages for proxy model registration (@blueyed).
  - Improvements to using migrations with custom user model (@aivins).
  - Removing sys.exit() in deleterevisions management command, allowing it to be used internally by Django projects (@tongwang).
  - Fixing some backwards-compatible admin deprecation warnings (Thomas Schreiber).
  - Fixing tests if RevisionMiddleware is used as a decorator in the parent project (@jmoldow).
  - Derived models, such as those generated by deferred querysets, now work.
* Thu Jan 23 2014 mcihar@suse.cz
- Update to version 1.8.0:
  + Django 1.6 compatibility (@niwibe & @meshy).
  + Removing type flag from Version model.
  + Using bulk_create to speed up revision creation.
  + Including docs in source distribution (@pquentin & @fladi).
  + Spanish translation (@alexander-ae).
  + Fixing edge-case bugs in revision middleware (@pricem & @oppianmatt).
- Improve package description
* Sat Sep 28 2013 p.drouand@gmail.com
- Update to version 1.7.1
  + Bugfixes when using a custom User model.
  + Minor bugfixes.
- Use download url as source url
- Add documentation from tarball
* Wed Dec 12 2012 alexandre@exatati.com.br
- Update to 1.6.5:
  - Support for Django 1.4.3.
* Mon Oct 29 2012 alexandre@exatati.com.br
- Update to 1.6.4:
  - Support for Django 1.4.2.
* Thu Sep  6 2012 alexandre@exatati.com.br
- Update to 1.6.3:
  - Fixing issue with reverting models with unique constraints in
    the admin.
  - Enforcing permissions in admin views.
* Tue Jul 31 2012 alexandre@exatati.com.br
- Update to 1.6.2:
  - Batch saving option in createinitialrevisions.
  - Suppressing warning for Django 1.4.1.
- Aditional changes from 1.6.1:
  - Swedish translation.
  - Fixing formating for PyPi readme and license.
  - Minor features and bugfixes.
* Tue Mar 27 2012 alexandre@exatati.com.br
- Update to 1.6.0:
  - Django 1.4 compatibility.
* Wed Oct 26 2011 alexandre@exatati.com.br
- Update to 1.5.1:
  - Sorry, no changelog atm.
* Mon Sep  5 2011 alexandre@exatati.com.br
- Update to 1.5:
  - Added in simplified low level API methods, and deprecated old
    low level API methods.
  - Added in support for multiple revision managers running in the
    same project.
  - Added in significant speedups for models with integer primary
    keys.
  - Added in cleanup improvements to patch generation helpers.
  - Minor bug fixes.
* Wed Apr 27 2011 alexandre@exatati.com.br
- Update to 1.4:
  - Sorry, no changelog.
* Tue Apr 19 2011 alexandre@exatati.com.br
- Regenerate spec file with py2pack.
* Mon Mar  7 2011 alexandre@exatati.com.br
- Update to 1.3.3.
* Fri Oct 22 2010 alexandre@exatati.com.br
- Update to 1.3.2.
* Mon May 31 2010 alexandre@exatati.com.br
- Update to 1.3.1.
* Mon May 31 2010 alexandre@exatati.com.br
- Update to 1.3;
- Spec file cleaned with spec-cleaner.
* Wed Mar  3 2010 alexandre@exatati.com.br
- Update to 1.2.1.
* Tue Oct 13 2009 alexandre@exatati.com.br
- Initial package (1.2) for openSUSE.
